# OSPFv3

Monitors status of OSPFv3 enabled devices

**Note**: on Cisco devices (IOS/IOS-XE) this checks will only work with default VRF and one OSPFv3 process.\
Also there can be onle one address family int the OSPFv3 process. Anything else nedds SNMPv3 contexts.

**Note: see the [Wiki](https://thl-cmk.hopto.org/gitlab/checkmk/vendor-independent/ospfv3/-/wikis/home) for a sample IOS OSPFv3 configuration**

Collection of OSPFv3 checks
*  *ospfv3_general*: monitors the OSPFv3 overall status
*  *ospfv3_area*: monitors OSPFv3 areas
*  *ospfv3_interface*: monitors OSPFv3 enabled interfaces
*  *ospfv3_neighbor*:  monitors OSPFv3 neighbors (IPv6 only)
*  *ospfv3_virtuallink*: monitors OSPFv3 virtual links (IPv6 only)

## Check Info *ospfv3_general*:

* *service*: this check creates the service *OSPFv3*
* *state*: **warning** if the OSPFv3 process is admin disabled (*shutdown*)
* *wato*: none
* *perfdata*:
    * LSA count
    * Etxternal LSA count
    * receive new LSA count

Sample output

![sample output](/doc/sample_ospfv3_general.png?raw=true "sample [SHORT TITLE]")

## Check Info *ospfv3_area*:

* *service*: this check creates one service per OSPFv3 area
* *state*: is always ok
* *wato*: none
* *perfdata*:
    * number of Autonomus System Border Routers (ASBRs)
    * number of Area Border Routers (ABRs)
    * Area LSA count
    * SPF runs
    * NSSA translator events

Sample output

![sample output](/doc/sample_ospfv3_area.png?raw=true "sample [SHORT TITLE]")

## Check Info *ospfv3_interface*:

* *service*: this check creates one service per OSPFv3 enabled interface
* *state*: 
    * **warning** if the OSPFv3 process is admin disabled (*shutdown*)
    * **warning** if the interface OSPFv3 state *waiting* or *standby*
    * **critical** if the interface OSPFv3 state *down*
* *wato*: none
* *perfdata*:
    * Link LSA count
    * Events

Sample output

![sample output](/doc/sample_ospfv3_interface.png?raw=true "sample [SHORT TITLE]")

## Check Info *ospfv3_neighbor*:

* *service*: this check creates one service for each OSPFv3 neighbor
* *state*: 
    * **warning** if the OSPFv3 neighbor state in *attempt*, *init*, *exchangeStart*, *exchange* or *loading*
    * **critical** if the OSPFv3 neighbor state is *down*
* *wato*: you can configure the warnining/critical states for the OSPFv3 process
* *perfdata*:
    * queue length
    * Events

Sample output

![sample output](/doc/sample_ospfv3_neighbor.png?raw=true "sample [SHORT TITLE]")

## Check Info *ospfv3_virtuallink*:

* *state*: 
    * **warning** if the OSPFv3 neighbor state in *attempt*, *init*, *exchangeStart*, *exchange* or *loading*
    * **critical** if the OSPFv3 neighbor state is *down*
* *wato*: you can configure the warnining/critical states for the OSPFv3 process
* *perfdata*:
    * queue length
    * Events

Sample output

![sample output](/doc/sample_ospfv3_virtuallink.png?raw=true "sample [SHORT TITLE]")
