#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
#
# Cisco OSPFv3 metrics plugin
#
# Author: Th.L.
# Date  : 2019-11-02
#
#


#####################################################################################################################
#
# define units for perfdata
#
#####################################################################################################################


# unit_info['uptime'] = {
#     'title': _('Uptime'),
#     'description': _('Timespan or Duration in seconds'),
#     'symbol': _('s'),
#     'render': lambda v: eigrp_render_uptime(v),
# }

######################################################################################################################
#
# map perfdata to metric, not really necessary but makes sure to use the right metrics
#
######################################################################################################################

check_metrics['check_mk-ospfv3_general'] = {
    'ospf_general_lsacount'   : {'name': 'ospfv3_general_lsacount', },
    'ospf_general_rxnewlsas'  : {'name': 'ospfv3_general_rxnewlsas', },
    'ospf_general_extlsacount': {'name': 'ospfv3_general_extlsacount', },
}

check_metrics['check_mk-ospfv3_neighbor'] = {
    'ospf_events'             : {'name': 'ospfv3_events', },
    'ospf_lsretransqlen'      : {'name': 'ospfv3_lsretransqlen', },
}

check_metrics['check_mk-ospfv3_interface'] = {
    'ospf_events'              : {'name': 'ospfv3_interface_events', },
    'ospf_linkscopelsacount'   : {'name': 'ospfv3_interface_linkscopelsacount', },
}

check_metrics['check_mk-ospfv3_area'] = {
    'ospf_spfruns'             : {'name': 'ospfv3_area_spfruns', },
    'ospf_bdrrtcount'          : {'name': 'ospfv3_area_bdrrtcount', },
    'ospf_asbdrrtrcount'       : {'name': 'ospfv3_area_asbdrrtrcount', },
    'ospf_scopelsacount'       : {'name': 'ospfv3_area_scopelsacount', },
    'ospf_nssatranslatorevents': {'name': 'ospfv3_area_nssatranslatorevents', },
}

check_metrics['check_mk-ospfv3_virtuallink'] = {
    'ospf_events'              : {'name': 'ospfv3_events', },
    'ospf_lsretransqlen'       : {'name': 'ospfv3_lsretransqlen', },
}

#####################################################################################################################
#
# define metrics for perfdata
#
#####################################################################################################################

metric_info['ospfv3_general_lsacount'] = {
    'title' : _('LSA count'),
    'unit'  : 'count',
    'color' : '26/a',
}
metric_info['ospfv3_general_rxnewlsas'] = {
    'title' : _('receive new LSA count'),
    'unit'  : 'count',
    'color' : '16/a',
}
metric_info['ospfv3_general_extlsacount'] = {
    'title' : _('Etxternal LSA count'),
    'unit'  : 'count',
    'color' : '16/a',
}

metric_info['ospfv3_events'] = {
    'title' : _('Events'),
    'unit'  : 'count',
    'color' : '26/a',
}
metric_info['ospfv3_lsretransqlen'] = {
    'title' : _('queue length'),
    'unit'  : 'count',
    'color' : '16/a',
}

metric_info['ospfv3_interface_events'] = {
    'title' : _('Events'),
    'unit'  : 'count',
    'color' : '26/a',
}
metric_info['ospfv3_interface_linkscopelsacount'] = {
    'title' : _('Link LSA count'),
    'unit'  : 'count',
    'color' : '16/a',
}

metric_info['ospfv3_area_spfruns'] = {
    'title': _('SPF runs'),
    'unit' : 'count',
    'color': '26/a',
}
metric_info['ospfv3_area_bdrrtcount'] = {
    'title' : _('# of ABRs'),
    'unit'  : 'count',
    'color' : '11/a',
}
metric_info['ospfv3_area_asbdrrtrcount'] = {
    'title': _('# of ASBRs'),
    'unit': 'count',
    'color': '22/a',
}
metric_info['ospfv3_area_scopelsacount'] = {
    'title': _('Area LSA count'),
    'unit': 'count',
    'color': '23/a',
}
metric_info['ospfv3_area_nssatranslatorevents'] = {
    'title': _('NSSA translator events'),
    'unit': 'count',
    'color': '11/a',
}

######################################################################################################################
#
# how to graph perdata
#
######################################################################################################################


graph_info.append({
    'title': _('LSA count'),
    'metrics': [
        ('ospfv3_general_lsacount', 'line'),
        ('ospfv3_general_rxnewlsas', 'line'),
        ('ospfv3_general_extlsacount', 'line'),
    ],
})

graph_info.append({
    'title': _('OSPFv3 Events'),
    'metrics': [
        ('ospfv3_events', 'area'),
    ],
})
graph_info.append({
    'title': _('Link state retransmission queue length'),
    'metrics': [
        ('ospfv3_lsretransqlen', 'area'),
    ],
})
graph_info.append({
    'title': _('Link scope LSA count'),
    'metrics': [
        ('ospfv3_interface_linkscopelsacount', 'area'),
    ],
})
graph_info.append({
    'title': _('SPF runs'),
    'metrics': [
        ('ospfv3_area_spfruns', 'area'),
    ],
})
graph_info.append({
    'title': _('Border router count'),
    'metrics': [
        ('ospfv3_area_bdrrtcount', 'area'),
        ('ospfv3_area_asbdrrtrcount', '-area'),
    ],
})
graph_info.append({
    'title': _('Area scope LSA count'),
    'metrics': [
        ('ospfv3_area_scopelsacount', 'area'),
    ],
})
graph_info.append({
    'title': _('NSSA translator events'),
    'metrics': [
        ('ospfv3_area_nssatranslatorevents', 'area'),
    ],
})


######################################################################################################################
#
# define perf-o-meter
#
######################################################################################################################

perfometer_info.append(('stacked', [
    {
        'type': 'linear',
        'segments': ['ospfv3_general_lsacount',
                     ],
        'total': 100,
    },
    {
        'type': 'linear',
        'segments': ['ospfv3_general_extlsacount',
                     ],
        'total': 100,
    }
]))

perfometer_info.append(('stacked', [
    {
        'type': 'linear',
        'segments': ['ospfv3_events',
                     ],
        'total': 100,
    },
    {
        'type': 'linear',
        'segments': ['ospfv3_lsretransqlen',
                     ],
        'total': 100,
    }
]))

perfometer_info.append(('stacked', [
    {
        'type': 'linear',
        'segments': ['ospfv3_interface_events',
                     ],
        'total': 1000,
    },
    {
        'type': 'linear',
        'segments': ['ospfv3_interface_linkscopelsacount',
                     ],
        'total': 1000,
    }
]))

perfometer_info.append(('stacked', [
    {
        'type': 'linear',
        'segments': ['ospfv3_area_spfruns',
                     ],
        'total': 1000,
    },
    {
        'type': 'linear',
        'segments': ['ospfv3_area_scopelsacount',
                     ],
        'total': 1000,
    }
]))
